%define major 0
%define libname %mklibname owfat %{major}

Summary:	Reimplement libdjb under GPL
Name:		libowfat
Version:	0.32
Release:	%mkrel 2
License:	GPLv2
Group:		Development/C
URL:		https://www.fefe.de/libowfat/
Source0:	https://www.fefe.de/%{name}/%{name}-%{version}.tar.xz
Source1:	https://www.fefe.de/%{name}/%{name}-%{version}.tar.xz.sig
Patch0:		havescope.patch
Patch1:		libowfat-0.32-mga-extern.patch
Patch2:		libowfat-0.30-shared.patch
Patch3:		libowfat-0.30-fix-gcc10-build.patch

BuildRequires:	dietlibc-devel >= 0.32

%description
libowfat is a library of general purpose APIs extracted from Dan
Bernstein's software, reimplemented and covered by the GNU General
Public License Version 2 (no later versions).

The API has been slightly extended (for example, I provide a
uint32_read function, and I extended the socket API to support
IPv6) where I found it necessary or beneficial in a specific
project.

Many of the functions I implement here have since been placed in
the public domain, so there are other sources to get this code
(except for my extensions obviously).  The implementations here
may not be as portable as the original versions; I tend to focus
on the Single Unix Specification and not on some obsolete legacy
systems found in the basements of some vintage hardware clubs.

I also provide man pages for many functions, mostly extracted from
Dan's web documentation or documentation found in earlier versions
of his software.  For some reason, he abandoned man pages in favor
of HTML recently.

On July 4 2002, Dan also placed his DNS routines and supporting
low level functions in the public domain, so I copy them here
instead of reimplementing them.

http://online.securityfocus.com/archive/1/280642
has an online version of the bugtraq posting.

%package -n %{libname}
Summary:	Libowfat shared libraries
Group:		System/Servers

%description -n %{libname}
This package contains libowfat shared libraries.

%package -n	%{name}-devel
Group:		Development/C
Summary:	Headers and static lib for libowfat development
Requires:	%{libname} = %{version}-%{release}

%description -n	%{name}-devel
Install this package if you want do compile applications using the
libowfat library.

%prep
%setup -q
%autopatch -p1
# the source is (illegally) redefining some reserved macros
find . -name '*.[ch]' -print0 | xargs -0 sed -i -e 's/__pure__/PURE/g' -e 's/__deprecated__/DEPRECATED/g'

%build
%set_build_flags
%make_build -f GNUmakefile \
    OPT_REG="$CFLAGS -fPIC -std=gnu17" \
	DIET=''

%install
make -f GNUmakefile \
	DIET='' \
	prefix=%{buildroot}%{_prefix} \
	MAN3DIR=%{buildroot}%{_mandir}/man3 \
    LIBDIR=%{buildroot}%{_libdir} \
    install

chmod 0755 %{buildroot}%{_libdir}/libowfat.so.%{version}
ln -s libowfat.so.%{version} %{buildroot}%{_libdir}/libowfat.so.%{major} 
ln -s libowfat.so.%{version} %{buildroot}%{_libdir}/libowfat.so

make -f GNUmakefile clean
rm -f Makefile
patch GNUmakefile -R -p1 < %{PATCH2}

make -f GNUmakefile \
    OPT_REG="$CFLAGS -fPIC -std=gnu17" \
    prefix="%{_libdir}/dietlibc" \
    DIET="%{_bindir}/diet -Os"

install -d %{buildroot}%{_libdir}/dietlibc
make -f GNUmakefile \
    prefix="%{buildroot}%{_libdir}/dietlibc" \
    LIBDIR="%{buildroot}%{_libdir}/dietlibc/lib" \
    DIET="%{_bindir}/diet -Os" \
    MAN3DIR="%{buildroot}%{_mandir}/man3" \
    install

# fix conflicting file (from openssl-devel)
mv %{buildroot}%{_mandir}/man3/buffer.3 \
    %{buildroot}%{_mandir}/man3/buffer-libowfat.3

%files -n %{libname}
%doc CHANGES README
%{_libdir}/libowfat.so.%{major}
%{_libdir}/libowfat.so.%{major}.*

%files -n %{name}-devel
%{_libdir}/libowfat.so
%{_includedir}/libowfat/*.h
%{_libdir}/dietlibc/lib/libowfat.a
%{_libdir}/dietlibc/include/libowfat/*.h
%{_mandir}/man3/*


%changelog
* Fri May 16 2025 ns80 <ns80> 0.32-2.mga10
+ Revision: 2183947
- revert to 0.32
- try to fix building with GCC 15
- new version 0.34

* Sat Nov 05 2022 danf <danf> 0.32-1.mga9
+ Revision: 1903548
- Update to ver. 0.32
- include files are now in a subdirectory
  Switch URLs to https:
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Aug 28 2020 joequant <joequant> 0.30-5.mga8
+ Revision: 1619473
- fix build with GCC 10

* Thu Feb 13 2020 umeabot <umeabot> 0.30-4.mga8
+ Revision: 1514354
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 0.30-3.mga7
+ Revision: 1299079
- Mageia 7 Mass Rebuild
+ wally <wally>
- fix license

* Thu Feb 11 2016 umeabot <umeabot> 0.30-2.mga6
+ Revision: 955612
- Mageia 6 Mass Rebuild

* Sun Sep 13 2015 pterjan <pterjan> 0.30-1.mga6
+ Revision: 878859
- Fix debug package
- Update to 0.30

* Sat Feb 14 2015 pterjan <pterjan> 0.28-10.mga5
+ Revision: 814957
- Fix build
+ boklm <boklm>
- clean spec
- imported package libowfat


* Sun Aug 30 2009 Raphaël Gertz <rapsys@mandriva.org> 0.28-9mdv2010.0
+ Revision: 422476
- Rebuild for x86_64
- Re-add static library

* Sat Aug 29 2009 Raphaël Gertz <rapsys@mandriva.org> 0.28-8mdv2010.0
+ Revision: 422301
- Rebuild for fixed lib major number

* Sat Aug 29 2009 Raphaël Gertz <rapsys@mandriva.org> 0.28-7mdv2010.0
+ Revision: 422299
- Fix missing symbolic links

* Sat Aug 29 2009 Raphaël Gertz <rapsys@mandriva.org> 0.28-6mdv2010.0
+ Revision: 422297
- Split in lib and lib-devel

* Sat Aug 29 2009 Raphaël Gertz <rapsys@mandriva.org> 0.28-5mdv2010.0
+ Revision: 422199
- Fix libdir path
  Rebuild for x86_64
- Rebuild for x86_64
- Should fix build on x86_64
- Re-up with 644 right
  Patch to build as shared library
- Remove for invalid 664 files right

* Tue Aug 25 2009 Oden Eriksson <oeriksson@mandriva.com> 0.28-1mdv2010.0
+ Revision: 420670
- 0.28

* Fri Aug 08 2008 Thierry Vignaud <tvignaud@mandriva.com> 0.27-3mdv2009.0
+ Revision: 267985
- rebuild early 2009.0 package (before pixel changes)

* Tue Jun 10 2008 Oden Eriksson <oeriksson@mandriva.com> 0.27-2mdv2009.0
+ Revision: 217541
- rebuilt against dietlibc-devel-0.32

* Sat Feb 02 2008 Funda Wang <fundawang@mandriva.org> 0.27-1mdv2008.1
+ Revision: 161360
- New version 0.27

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 0.24-1mdv2008.1
+ Revision: 136557
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request


* Sat Dec 09 2006 Oden Eriksson <oeriksson@mandriva.com> 0.24-1mdv2007.0
+ Revision: 94247
- Import libowfat

* Sat Apr 29 2006 Oden Eriksson <oeriksson@mandriva.com> 0.24-1mdk
- 0.24

* Tue Feb 01 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 0.21-1mdk
- 0.21

* Fri Aug 06 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.20-1mdk
- 0.20

* Tue Jun 29 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 0.19.2-1mdk
- 0.19.2

